aboutsummaryrefslogtreecommitdiffstats
path: root/src/modules/objects/KvsObject_widget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/objects/KvsObject_widget.cpp')
-rw-r--r--src/modules/objects/KvsObject_widget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/modules/objects/KvsObject_widget.cpp b/src/modules/objects/KvsObject_widget.cpp
index 9eb2fb00b..bee2b9fa5 100644
--- a/src/modules/objects/KvsObject_widget.cpp
+++ b/src/modules/objects/KvsObject_widget.cpp
@@ -193,10 +193,10 @@ const char * const widgettypes_tbl[] = {
All the other widget-type classes inherit from this one.
@functions:
!fn: $show()
- Shows this widget and the children.
+ Shows this widget and the child items.
See also [classfnc]$hide[/classfnc]() and [classfnc]$isVisible[/classfnc].
!fn: $hide()
- Hides this widget (and conseguently all the children).
+ Hides this widget (and conseguently all the child items).
See also [classfnc]$show[/classfnc]() and [classfnc]$isVisible[/classfnc].
!fn: $repaint()
Repaints the widget directly by calling [classfnc]$paintEvent[/classfnc]() immediately.
@@ -590,7 +590,7 @@ const char * const widgettypes_tbl[] = {
// ... now that I think about it, it
// may happen that widget() will be zero here too:
// If the Qt "physical" widget gets destroyed
// by some external factor (for example when children
// of a wrapper widget destroyed by KVIrc).
//
// as a convention:
@@ -590,7 +590,7 @@ const char * const widgettypes_tbl[] = {
// may happen that widget() will be zero here too:
// If the Qt "physical" widget gets destroyed
-// by some external factor (for example when children
+// by some external factor (for example when child
// of a wrapper widget destroyed by KVIrc).
//